@@ -45,7 +45,7 @@ from ..models import CartItem
 from .serializers import (ChargeSerializer, InvoicableSerializer,
     NoModelSerializer, PlanRelatedField, ValidationErrorSerializer)
 
-#pylint: disable=no-init,old-style-class
+#pylint: disable=no-init
 LOGGER = logging.getLogger(__name__)
 
 
@@ -371,7 +371,7 @@ class CouponRedeemAPIView(GenericAPIView):
 
     .. code-block:: http
 
-         POST /api/redeem HTTP/1.1
+         POST /api/cart/redeem HTTP/1.1
 
     .. code-block:: json
 
